
import { useState, useEffect } from 'react';
import { Dialog, DialogContent } from '@/components/ui/dialog';
import { Play } from 'lucide-react';
import OptimizedHeroImage from "@/components/OptimizedHeroImage";
import FeatureCardsSection from "@/components/FeatureCardsSection";
import TestimonialCardsSection from "@/components/TestimonialCardsSection";
import LazyCalendlySection from "@/components/LazyCalendlySection";
import CriticalCSS from "@/components/CriticalCSS";
import OptimizedLazySection from "@/components/OptimizedLazySection";
import { MetaTagService } from '@/utils/metaTagService';

const WEBP_SUPPORT_CHECK = () => {
  return new Promise((resolve) => {
    const webP = new Image();
    webP.onload = webP.onerror = () => {
      resolve(webP.height === 2);
    };
    webP.src = "data:image/webp;base64,UklGRjoAAABXRUJQVlA4IC4AAACyAgCdASoCAAIALmk0mk0iIiIiIgBoSygABc6WWgAA/veff/0PP8bA//LwYAAA";
  });
};

const MOBILE_HERO_PNG = "/lovable-uploads/53e15945-ceab-425f-a09b-1df1cfc6989f.png";
const DESKTOP_HERO_WEBP = "/lovable-uploads/53e15945-ceab-425f-a09b-1df1cfc6989f.webp";

const Index = () => {
  const [imageLoaded, setImageLoaded] = useState(false);
  const [isVideoModalOpen, setIsVideoModalOpen] = useState(false);
  const [useWebp, setUseWebp] = useState(false);

  // WebP support detection
  useEffect(() => {
    WEBP_SUPPORT_CHECK().then((supported) => {
      setUseWebp(!!supported);
    });
  }, []);

  // Update meta tags and title immediately
  useEffect(() => {
    const heroTitle = 'CAD for architects. But much better...';
    const heroDescription = 'Meet the system for modern architectural development.';
    const heroImage = useWebp ? DESKTOP_HERO_WEBP : MOBILE_HERO_PNG;
    
    // Update all meta tags using the service
    MetaTagService.updatePageMeta(heroTitle, heroDescription, heroImage);
    
    // Set favicon
    MetaTagService.setFavicon('/lovable-uploads/89d533c3-7013-42c7-a7d2-61e7dc688c0b.png');

    return () => {
      // Reset to default when component unmounts
      document.title = 'Rayon.design - CAD for architects';
    };
  }, [useWebp]);

  // Preload hero image
  useEffect(() => {
    const heroImage = useWebp ? DESKTOP_HERO_WEBP : MOBILE_HERO_PNG;
    const img = new Image();
    img.fetchPriority = 'high';
    img.decoding = 'sync';
    img.onload = () => setImageLoaded(true);
    img.onerror = () => setImageLoaded(true); // Still show page even if image fails
    img.src = heroImage;
  }, [useWebp]);

  const handleWatchDemo = () => {
    setIsVideoModalOpen(true);
  };

  const handleStartBuilding = () => {
    window.open('https://rayon.design/', '_blank');
  };

  const handleBookDemo = () => {
    window.open('https://calendly.com/support-demo-jvo/rayon-demo-premium-eu-clone-1', '_blank');
  };

  const featureCards = [
    {
      title: "Parametric Design",
      text: "Create complex architectural forms with intuitive parametric controls. Adjust parameters in real-time and see your design evolve instantly.",
      image_url: "/lovable-uploads/76b626f2-f662-49b9-b5a6-767c5e5f9e2b.png"
    },
    {
      title: "Real-time Collaboration", 
      text: "Work seamlessly with your team in real-time. Share designs, leave comments, and iterate together from anywhere in the world.",
      image_url: "/lovable-uploads/a39af904-54d8-40c6-9b1b-c68ab2f2ee27.png"
    },
    {
      title: "Performance Analytics",
      text: "Analyze your building's performance metrics including energy efficiency, structural integrity, and environmental impact in real-time.",
      image_url: "/lovable-uploads/d6f340ad-74b8-4037-8d0c-1abc25c8190f.png"
    },
    {
      title: "Smart Documentation",
      text: "Generate comprehensive project documentation automatically. From technical drawings to compliance reports, everything is created and updated in real-time.",
      image_url: "/lovable-uploads/b540d158-7917-4b6e-a393-a60bb3258b09.png"
    }
  ];

  const testimonialCards = [
    {
      quote: "Rayon has completely transformed our design workflow. The parametric tools are incredibly intuitive and powerful.",
      name: "Sarah Chen",
      title: "Principal Architect at Foster + Partners",
      avatar_url: "https://images.unsplash.com/photo-1494790108755-2616b612b1f5?w=150&h=150&fit=crop&crop=face"
    },
    {
      quote: "The real-time collaboration features have made our remote work seamless. Our productivity has increased by 40%.",
      name: "Marcus Rodriguez",
      title: "Design Director at Zaha Hadid Architects",
      avatar_url: "https://images.unsplash.com/photo-1472099645785-5658abf4ff4e?w=150&h=150&fit=crop&crop=face"
    },
    {
      quote: "The performance analytics give us insights we never had before. It's like having a building physicist on our team.",
      name: "Emily Watson",
      title: "Senior Architect at BIG",
      avatar_url: "https://images.unsplash.com/photo-1438761681033-6461ffad8d80?w=150&h=150&fit=crop&crop=face"
    }
  ];

  return (
    <div 
      className="min-h-screen bg-gray-900 text-white font-['Geist'] relative"
      style={{
        backgroundImage: "url(/lovable-uploads/c00ddefc-b244-4071-97eb-05021ebc4b89.png)",
        backgroundSize: "auto",
        backgroundRepeat: "repeat",
        backgroundPosition: "top left"
      }}
    >
      <CriticalCSS />
      <div className="absolute inset-0 bg-gray-900/90 z-0"></div>
      <div className="relative z-10">
        {/* Hero Section */}
        <div className="relative pt-16 pb-8 py-[41px]">
          <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
            <div className="max-w-4xl mx-auto text-center py-[26px]">
              <h1 className="text-5xl md:text-7xl font-bold leading-[0.85] mb-8 tracking-tighter text-white">
                CAD for architects. But much better...
              </h1>
              
              <div className="max-w-2xl mx-auto mb-12">
                <p className="text-xl text-gray-400 leading-relaxed mb-4">
                  Meet the system for modern architectural development.
                </p>
              </div>
              
              <div className="flex items-center justify-center space-x-4 mb-16">
                <button 
                  onClick={handleStartBuilding}
                  className="bg-blue-600 text-white px-8 py-4 md:px-12 md:py-6 rounded-lg font-semibold hover:bg-blue-700 transition-colors text-sm md:text-lg"
                >
                  Start Building
                </button>
                <button 
                  onClick={handleWatchDemo}
                  className="bg-gray-800 text-white px-8 py-4 md:px-12 md:py-6 rounded-lg font-semibold hover:bg-gray-700 transition-colors border border-gray-700 text-sm md:text-lg flex items-center space-x-2"
                >
                  <Play className="w-5 h-5" />
                  <span>Watch Demo</span>
                </button>
              </div>
            </div>
            
            {/* Hero Image */}
            <div className="max-w-6xl mx-auto">
              <OptimizedHeroImage
                mobileSrc={MOBILE_HERO_PNG}
                desktopSrc={useWebp ? DESKTOP_HERO_WEBP : MOBILE_HERO_PNG}
                webpMobileSrc={useWebp ? DESKTOP_HERO_WEBP : undefined}
                webpDesktopSrc={useWebp ? DESKTOP_HERO_WEBP : undefined}
                alt="Rayon.design CAD interface for architects"
                width={2048}
                height={1184}
                className="rounded-2xl overflow-hidden shadow-2xl"
                priority={true}
              />
            </div>
          </div>
        </div>

        {/* Feature Cards Section */}
        <OptimizedLazySection>
          <FeatureCardsSection cards={featureCards} />
        </OptimizedLazySection>
        
        {/* Testimonial Cards Section */}
        <OptimizedLazySection>
          <TestimonialCardsSection cards={testimonialCards} />
        </OptimizedLazySection>

        {/* Calendly Section */}
        <OptimizedLazySection>
          <LazyCalendlySection embedUrl="https://calendly.com/support-demo-jvo/rayon-demo-premium-eu-clone-1" />
        </OptimizedLazySection>

        {/* Footer */}
        <footer className="py-12 px-4 sm:px-6 lg:px-8 border-t border-gray-800">
          <div className="max-w-6xl mx-auto text-center">
            <p className="text-gray-400">
              © 2025 Rayon.design
            </p>
          </div>
        </footer>
      </div>

      {/* Video Modal Dialog */}
      <Dialog open={isVideoModalOpen} onOpenChange={setIsVideoModalOpen}>
        <DialogContent className="max-w-4xl p-0 bg-black border-0">
          <div className="aspect-video">
            <iframe
              src="https://player.vimeo.com/video/1091321536?autoplay=1&controls=1&loop=1"
              width="100%"
              height="100%"
              frameBorder="0"
              allow="autoplay; fullscreen; picture-in-picture"
              allowFullScreen
              title="Demo Video"
              className="rounded-lg"
            ></iframe>
          </div>
        </DialogContent>
      </Dialog>
    </div>
  );
};

export default Index;
